Adc

Struct Adc 

pub struct Adc<F> { /* private fields */ }

Implementations

Source

impl Adc<Unsigned32>

pub fn new_u32(adc: ADC, fractional: bool) -> Self

Create an Adc instance (unsigned 32-bit data format). fractional == true selects a fractional number format.

pub fn read(&self, index: usize) -> u32

Read from the ADC buffer. index must be less than or equal to 15.

Source

impl Adc<Signed32>

pub fn new_i32(adc: ADC, fractional: bool) -> Self

Create an Adc instance (signed 32-bit data format). fractional == true selects a fractional number format.

pub fn read(&self, index: usize) -> i32

Read from the ADC buffer. index must be less than or equal to 15.

Source

impl Adc<Unsigned16>

pub fn new_u16(adc: ADC, fractional: bool) -> Self

Create an Adc instance (unsigned 16-bit data format). fractional == true selects a fractional number format.

pub fn read(&self, index: usize) -> u16

Read from the ADC buffer. index must be less than or equal to 15.

Source

impl Adc<Signed16>

pub fn new_i16(adc: ADC, fractional: bool) -> Self

Create an Adc instance (signed 16-bit data format). fractional == true selects a fractional number format.

pub fn read(&self, index: usize) -> i16

Read from the ADC buffer. index must be less than or equal to 15.

Source

impl<F> Adc<F>

pub fn configure(&mut self, config: &AdcConfiguration)

configure and activate the ADC

pub fn select_pos_input(&mut self, input: InputScan)

Select positive input for sample A

pub fn select_neg_input(&mut self, input: NegativeInput)

Select negative input for sample A

pub fn select_pos_alt_input(&mut self, input: u8)

Select positive input for sample B (alternate sample)

pub fn select_neg_alt_input(&mut self, input: NegativeInput)

Select negative input for sample B (alternate sample)

pub fn start_sampling(&mut self)

Manually start a sampling period. Use only when auto_sample is not active.

pub fn start_conversion(&mut self)

Manually start a conversion period. Use only when the ConversionTrigger is Manual.

pub fn done(&self) -> bool

Check if conversion is complete. To be used when sampling is stated manually.

pub fn free(self) -> ADC

return the ADC consuming the Adc instance