pub enum Error {
InvalidState,
InvalidArgument,
}Expand description
Clock module errors
Variants
InvalidState
Operation cannot performed in the current state of the clock module
InvalidArgument
Value is out of range supported by the hardware