Osc

Struct Osc 

pub struct Osc { /* private fields */ }

Implementations

Source

impl Osc

pub const fn new(osc: OSC, sysclock: Hertz) -> Osc

Create a new Osc from a possibly constant sysclock value. The sysclock value should be set to the core clock resulting from the configuration words and, if a crystal oscillator is used, the crystal frequency.

pub const fn new_with_refclock(osc: OSC, sysclock: Hertz) -> (Osc, Refclock)

Create a new Osc and Refclock from a possibly constant sysclock value. The sysclock value should be set to the core clock resulting from the configuration words and, if a crystal oscillator is used, the crystal frequency.

pub fn sysclock(&self) -> Hertz

Get the sysclock

pub fn pb_clock(&self) -> Hertz

Determine the peripheral clock frequency based on the sysclock value and the peripheral clock divider setting