#[repr(u32)]pub enum Fscl {
F100KHZ = 204_248,
F400KHZ = 872_600,
F1000KHZ = 2_525_253,
}Expand description
I2C clock frequency specifier The values of this enum correspond to the divisor values mentioned in the reference manual
Variants