Interrupt

Enum Interrupt 

#[repr(u16)]
pub enum Interrupt {
Show 44 variants CORE_TIMER = 0, CORE_SOFTWARE_0 = 1, CORE_SOFTWARE_1 = 2, EXTERNAL_0 = 3, TIMER_1 = 4, INPUT_CAPTURE_1 = 5, OUTPUT_COMPARE_1 = 6, EXTERNAL_1 = 7, TIMER_2 = 8, INPUT_CAPTURE_2 = 9, OUTPUT_COMPARE_2 = 10, EXTERNAL_2 = 11, TIMER_3 = 12, INPUT_CAPTURE_3 = 13, OUTPUT_COMPARE_3 = 14, EXTERNAL_3 = 15, TIMER_4 = 16, INPUT_CAPTURE_4 = 17, OUTPUT_COMPARE_4 = 18, EXTERNAL_4 = 19, TIMER_5 = 20, INPUT_CAPTURE_5 = 21, OUTPUT_COMPARE_5 = 22, ADC = 23, FAIL_SAFE_MONITOR = 24, RTCC = 25, FCE = 26, COMPARATOR_1 = 27, COMPARATOR_2 = 28, COMPARATOR_3 = 29, USB_1 = 30, SPI_1 = 31, UART_1 = 32, I2C_1 = 33, CHANGE_NOTICE = 34, PMP = 35, SPI_2 = 36, UART_2 = 37, I2C_2 = 38, CTMU = 39, DMA_0 = 40, DMA_1 = 41, DMA_2 = 42, DMA_3 = 43,
}
Interrupt vector (from PAC)

One interrupt vector may assigned more than one interrupt source. Enumeration of all the interrupts.

Variants



CORE_TIMER = 0

0 - CORE_TIMER



CORE_SOFTWARE_0 = 1

1 - CORE_SOFTWARE_0



CORE_SOFTWARE_1 = 2

2 - CORE_SOFTWARE_1



EXTERNAL_0 = 3

3 - EXTERNAL_0



TIMER_1 = 4

4 - TIMER_1



INPUT_CAPTURE_1 = 5

5 - INPUT_CAPTURE_1



OUTPUT_COMPARE_1 = 6

6 - OUTPUT_COMPARE_1



EXTERNAL_1 = 7

7 - EXTERNAL_1



TIMER_2 = 8

8 - TIMER_2



INPUT_CAPTURE_2 = 9

9 - INPUT_CAPTURE_2



OUTPUT_COMPARE_2 = 10

10 - OUTPUT_COMPARE_2



EXTERNAL_2 = 11

11 - EXTERNAL_2



TIMER_3 = 12

12 - TIMER_3



INPUT_CAPTURE_3 = 13

13 - INPUT_CAPTURE_3



OUTPUT_COMPARE_3 = 14

14 - OUTPUT_COMPARE_3



EXTERNAL_3 = 15

15 - EXTERNAL_3



TIMER_4 = 16

16 - TIMER_4



INPUT_CAPTURE_4 = 17

17 - INPUT_CAPTURE_4



OUTPUT_COMPARE_4 = 18

18 - OUTPUT_COMPARE_4



EXTERNAL_4 = 19

19 - EXTERNAL_4



TIMER_5 = 20

20 - TIMER_5



INPUT_CAPTURE_5 = 21

21 - INPUT_CAPTURE_5



OUTPUT_COMPARE_5 = 22

22 - OUTPUT_COMPARE_5



ADC = 23

23 - ADC



FAIL_SAFE_MONITOR = 24

24 - FAIL_SAFE_MONITOR



RTCC = 25

25 - RTCC



FCE = 26

26 - FCE



COMPARATOR_1 = 27

27 - COMPARATOR_1



COMPARATOR_2 = 28

28 - COMPARATOR_2



COMPARATOR_3 = 29

29 - COMPARATOR_3



USB_1 = 30

30 - USB_1



SPI_1 = 31

31 - SPI_1



UART_1 = 32

32 - UART_1



I2C_1 = 33

33 - I2C_1



CHANGE_NOTICE = 34

34 - CHANGE_NOTICE



PMP = 35

35 - PMP



SPI_2 = 36

36 - SPI_2



UART_2 = 37

37 - UART_2



I2C_2 = 38

38 - I2C_2



CTMU = 39

39 - CTMU



DMA_0 = 40

40 - DMA_0



DMA_1 = 41

41 - DMA_1



DMA_2 = 42

42 - DMA_2



DMA_3 = 43

43 - DMA_3

Implementations

Source

impl Interrupt

pub fn try_from(value: u8) -> Result<Interrupt, TryFromInterruptError>

Attempt to convert a given value into an Interrupt