Int

Struct Int 

pub struct Int { /* private fields */ }
Access to interrupt controller.

Implementations

Source

impl Int

pub fn new(int: INT) -> Int

Create a new instance. Configures the interrupt controller to work in the Multi-vectored mode. The Cause register of the MIPS core must be already configured for use with External Interrupt Controller (EIC); done by startup code.

pub fn ei(&self, s: InterruptSource)

Enable interrupts for a specific source

pub fn di(&self, s: InterruptSource)

Disable interrupts for a specific source

pub fn is_ie(&self, s: InterruptSource) -> bool

Check if interrupts for a specific source are enabled

pub fn get_if(&self, s: InterruptSource) -> bool

Read the interrupt flag of a specific interrupt source

pub fn clear_if(&self, s: InterruptSource)

Clear the interrupt flag of a specific interrupt source To be called before terminating an ISR.

pub fn set_if(&self, s: InterruptSource)

Set the interrupt flag of a specific interrupt source

pub fn set_ipl(&self, iv: Interrupt, ipl: Ipl)

Set the interrupt priority level of a specific interrupt vector

pub fn ipl(&self, iv: Interrupt) -> Ipl

Get the interrupt priority level of a specific interrupt vector

pub fn set_isl(&self, iv: Interrupt, isl: Isl)

Set the interrupt sub priority level of a specific interrupt vector

pub fn isl(&self, iv: Interrupt) -> Isl

Get the interrupt sub priority level of a specific interrupt vector