pub enum OcConfig {
Off,
RisingSlope(u32),
FallingSlope(u32),
Toggle(u32),
SinglePulse(u32, u32),
ContinuousPulses(u32, u32),
}Expand description
Output compare configuration (excluding PWM modes)
Variants
Off
No operation
RisingSlope(u32)
Rising slope when the timer is equal to the specified value
FallingSlope(u32)
Falling slope when the timer is equal to the specified value
Toggle(u32)
Toggle when the timer is equal to the specified value
SinglePulse(u32, u32)
Single pulse with values defining the rising edge and falling edge, respectively
ContinuousPulses(u32, u32)
Continuous pulses with values defining the rising edges and falling edges, respectively