Oc

Struct Oc 

pub struct Oc<OCMP, TIMEBASE> { /* private fields */ }
Output compare modules configured for non-PWM output compare operations

Implementations

Source

impl Oc<OCMP1, TimebaseUninit>

pub fn oc1(ocmp: OCMP1, stop_in_idle_mode: bool) -> Self

Source

impl<TIMEBASE> Oc<OCMP1, TIMEBASE>

pub fn timebase16even(self) -> Oc<OCMP1, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Oc<OCMP1, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Oc<OCMP1, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn free(self) -> OCMP1

Deactivate the output compare module and return the PAC object

pub fn turn_off(&mut self)

Turn output compare module off

Source

impl Oc<OCMP1, Timebase16even>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP1, Timebase16odd>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP1, Timebase32>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP2, TimebaseUninit>

pub fn oc2(ocmp: OCMP2, stop_in_idle_mode: bool) -> Self

Source

impl<TIMEBASE> Oc<OCMP2, TIMEBASE>

pub fn timebase16even(self) -> Oc<OCMP2, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Oc<OCMP2, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Oc<OCMP2, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn free(self) -> OCMP2

Deactivate the output compare module and return the PAC object

pub fn turn_off(&mut self)

Turn output compare module off

Source

impl Oc<OCMP2, Timebase16even>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP2, Timebase16odd>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP2, Timebase32>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP3, TimebaseUninit>

pub fn oc3(ocmp: OCMP3, stop_in_idle_mode: bool) -> Self

Source

impl<TIMEBASE> Oc<OCMP3, TIMEBASE>

pub fn timebase16even(self) -> Oc<OCMP3, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Oc<OCMP3, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Oc<OCMP3, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn free(self) -> OCMP3

Deactivate the output compare module and return the PAC object

pub fn turn_off(&mut self)

Turn output compare module off

Source

impl Oc<OCMP3, Timebase16even>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP3, Timebase16odd>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP3, Timebase32>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP4, TimebaseUninit>

pub fn oc4(ocmp: OCMP4, stop_in_idle_mode: bool) -> Self

Source

impl<TIMEBASE> Oc<OCMP4, TIMEBASE>

pub fn timebase16even(self) -> Oc<OCMP4, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Oc<OCMP4, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Oc<OCMP4, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn free(self) -> OCMP4

Deactivate the output compare module and return the PAC object

pub fn turn_off(&mut self)

Turn output compare module off

Source

impl Oc<OCMP4, Timebase16even>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP4, Timebase16odd>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP4, Timebase32>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP5, TimebaseUninit>

pub fn oc5(ocmp: OCMP5, stop_in_idle_mode: bool) -> Self

Source

impl<TIMEBASE> Oc<OCMP5, TIMEBASE>

pub fn timebase16even(self) -> Oc<OCMP5, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Oc<OCMP5, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Oc<OCMP5, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn free(self) -> OCMP5

Deactivate the output compare module and return the PAC object

pub fn turn_off(&mut self)

Turn output compare module off

Source

impl Oc<OCMP5, Timebase16even>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP5, Timebase16odd>

pub fn turn_on(&mut self, config: OcConfig)

Source

impl Oc<OCMP5, Timebase32>

pub fn turn_on(&mut self, config: OcConfig)