Pwm

Struct Pwm 

pub struct Pwm<OCMP, TIMEBASE> { /* private fields */ }
Output compare modules configured for PWM

Implementations

Source

impl Pwm<OCMP1, TimebaseUninit>

pub fn oc1(ocmp: OCMP1, enable_fault_pin: bool, stop_in_idle_mode: bool) -> Self

Initialize the output compare module for PWM.

The respective timer must be set up previously. The HAL code for PWM reads the respective timer period register to get the maximum duty cycle value.

Source

impl<TIMEBASE> Pwm<OCMP1, TIMEBASE>

pub fn timebase16even(self) -> Pwm<OCMP1, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Pwm<OCMP1, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Pwm<OCMP1, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn fault(&self) -> bool

Get fault state

Returns false if fault pin is not enabled.

pub fn on(&mut self)

Turn PWM on.

Can be used to re-enable PWM after a fault has been detected.

pub fn off(&mut self)

Turn PWM off.

pub fn free(self) -> OCMP1

Deactivate the output compare module and return the PAC object

Source

impl Pwm<OCMP2, TimebaseUninit>

pub fn oc2(ocmp: OCMP2, enable_fault_pin: bool, stop_in_idle_mode: bool) -> Self

Initialize the output compare module for PWM.

The respective timer must be set up previously. The HAL code for PWM reads the respective timer period register to get the maximum duty cycle value.

Source

impl<TIMEBASE> Pwm<OCMP2, TIMEBASE>

pub fn timebase16even(self) -> Pwm<OCMP2, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Pwm<OCMP2, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Pwm<OCMP2, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn fault(&self) -> bool

Get fault state

Returns false if fault pin is not enabled.

pub fn on(&mut self)

Turn PWM on.

Can be used to re-enable PWM after a fault has been detected.

pub fn off(&mut self)

Turn PWM off.

pub fn free(self) -> OCMP2

Deactivate the output compare module and return the PAC object

Source

impl Pwm<OCMP3, TimebaseUninit>

pub fn oc3(ocmp: OCMP3, enable_fault_pin: bool, stop_in_idle_mode: bool) -> Self

Initialize the output compare module for PWM.

The respective timer must be set up previously. The HAL code for PWM reads the respective timer period register to get the maximum duty cycle value.

Source

impl<TIMEBASE> Pwm<OCMP3, TIMEBASE>

pub fn timebase16even(self) -> Pwm<OCMP3, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Pwm<OCMP3, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Pwm<OCMP3, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn fault(&self) -> bool

Get fault state

Returns false if fault pin is not enabled.

pub fn on(&mut self)

Turn PWM on.

Can be used to re-enable PWM after a fault has been detected.

pub fn off(&mut self)

Turn PWM off.

pub fn free(self) -> OCMP3

Deactivate the output compare module and return the PAC object

Source

impl Pwm<OCMP4, TimebaseUninit>

pub fn oc4(ocmp: OCMP4, enable_fault_pin: bool, stop_in_idle_mode: bool) -> Self

Initialize the output compare module for PWM.

The respective timer must be set up previously. The HAL code for PWM reads the respective timer period register to get the maximum duty cycle value.

Source

impl<TIMEBASE> Pwm<OCMP4, TIMEBASE>

pub fn timebase16even(self) -> Pwm<OCMP4, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Pwm<OCMP4, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Pwm<OCMP4, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn fault(&self) -> bool

Get fault state

Returns false if fault pin is not enabled.

pub fn on(&mut self)

Turn PWM on.

Can be used to re-enable PWM after a fault has been detected.

pub fn off(&mut self)

Turn PWM off.

pub fn free(self) -> OCMP4

Deactivate the output compare module and return the PAC object

Source

impl Pwm<OCMP5, TimebaseUninit>

pub fn oc5(ocmp: OCMP5, enable_fault_pin: bool, stop_in_idle_mode: bool) -> Self

Initialize the output compare module for PWM.

The respective timer must be set up previously. The HAL code for PWM reads the respective timer period register to get the maximum duty cycle value.

Source

impl<TIMEBASE> Pwm<OCMP5, TIMEBASE>

pub fn timebase16even(self) -> Pwm<OCMP5, Timebase16even>

Select the even numbered 16-bit timer as the time base.

pub fn timebase16odd(self) -> Pwm<OCMP5, Timebase16odd>

Select the odd numbered 16-bit timer as the time base.

pub fn timebase32(self) -> Pwm<OCMP5, Timebase32>

Select both 16-bit timers as a 32-bit time base.

pub fn fault(&self) -> bool

Get fault state

Returns false if fault pin is not enabled.

pub fn on(&mut self)

Turn PWM on.

Can be used to re-enable PWM after a fault has been detected.

pub fn off(&mut self)

Turn PWM off.

pub fn free(self) -> OCMP5

Deactivate the output compare module and return the PAC object