Tx

Struct Tx 

pub struct Tx<UART> { /* private fields */ }
Uart transmitter

Implementations

Source

impl Tx<UART1>

pub fn transmit_break(&mut self)

Flush the transmit buffer and then send a break character.

Source

impl Tx<UART2>

pub fn transmit_break(&mut self)

Flush the transmit buffer and then send a break character.