pub struct Osc { /* private fields */ }Implementations
Sourceimpl Osc
impl Osc
Sourcepub const fn new(osc: OSC, sysclock: Hertz) -> Osc
pub const fn new(osc: OSC, sysclock: Hertz) -> Osc
Create a new Osc from a possibly constant sysclock value. The sysclock
value should be set to the core clock resulting from the configuration
words and, if a crystal oscillator is used, the crystal frequency.
Sourcepub const fn new_with_refclock(osc: OSC, sysclock: Hertz) -> (Osc, Refclock)
pub const fn new_with_refclock(osc: OSC, sysclock: Hertz) -> (Osc, Refclock)
Create a new Osc and Refclock from a possibly constant sysclock
value. The sysclock value should be set to the core clock resulting from
the configuration words and, if a crystal oscillator is used, the
crystal frequency.