pub type Error = ErrorKind;Expand description
SPI error
Aliased Type
pub enum Error {
Overrun,
ModeFault,
FrameFormat,
ChipSelectFault,
Other,
}Variants
Overrun
The peripheral receive buffer was overrun.
ModeFault
Multiple devices on the SPI bus are trying to drive the slave select pin, e.g. in a multi-master setup.
FrameFormat
Received data does not conform to the peripheral configuration.
ChipSelectFault
An error occurred while asserting or deasserting the Chip Select pin.
Other
A different error occurred. The original error may contain more information.